@@ -13,14 +13,24 @@ def send_result(arguments, start_time, end_time, return_code, text):
     config = configparser.ConfigParser()
     config.read('config.ini')
 
+    token = config['telegram']['token']
+    chat_id = config['telegram']['telegram_id']
+
     title = 'Success' if return_code == 0 else "Error"
     command = ' '.join(arguments)
     execution_time = end_time - start_time
+    #
+    # with open('log.txt', 'w') as fout:
+    #     fout.write(text)
+    #
 
-    message = f"*{title}* \nCommand: `{command}` \nExecution time: `{execution_time}` \n\nLog output:\n ```{text}```"
+    message = f"*{title}* \nCommand: `{command}` \nExecution time: `{execution_time}` \n\nLog output will be below."
 
-    bot = Bot(config['telegram']['token'])
-    bot.send_message(config['telegram']['telegram_id'], message, parse_mode='Markdown')
+    bot = Bot(token)
+    bot.send_message(chat_id, message, parse_mode='Markdown')
+    #
+    # with open('log.txt', 'rb') as fin:
+    bot.send_document(chat_id, text)
 
 
 def notify(arguments):
